<?php
    /**
     * Copyright 2005 Zervaas Enterprises (www.zervaas.com.au)
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *     http://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     *
     *
     * This class is used to validate a Smarty template
     *
     * @copyright 2005 Zervaas Enterprises
     * @author Quentin Zervaas
     */
 
 
    require_once('./inc/t_lite/class.template.php');
    require_once('./inc/t_lite/class.compiler.php');
 
    class SmartyValidator extends Template_Lite_Compiler
    {
        /**
         * Class constructor
         *
         * @access public
         */
        function SmartyValidator()
        {
            $this->Template_Lite();
            $this->Template_Lite_Compiler();
			$this->left_delimiter = '<!--{';
			$this->right_delimiter = '}-->';
        }
 
        /**
         * Validate a Smarty template
         *
         * This functions parses and validates the passed template, returning
         * an array of erros
         *
         * @access  public
         * @param   string  $str        The template to validate
         * @param   array   $options    Validator run-time options
         *                  +validateResources   bool   Whether or not to
         *                                       validate include resources
         *                                       (e.g. from {include file='...'})
         * @return  array               The errors found. Empty array means
         *                              valid template
         */
        function validateTemplate($str, $options = array())
        {
            $this->errors = array();
            $this->includes = array();
 
            if (!is_array($options))
                $options = array();
 
            $options['validateResources'] = isset($options['validateResources']) ?
                                            (bool) $options['validateResources'] :
                                            true;
 
            // first check the syntax is good
            $compiled_content = '';
            $compiled_content= $this->_compile_file($str);
                // we can't stop processing after a fatal error without
                // hacking Smarty so we just hide PHP errors instead.

            // now check included resources
            if ($options['validateResources']) {
                foreach ($this->includes as $include) {
                    if (!array_key_exists('file', $include))
                        continue;
 
                    $resource_name = substr(substr($include['file'], 1), 0, -1);
                        // strips the quotes off each end
 
                    $params = array('resource_name' => $resource_name);
                    $info = $this->_fetch_resource_info($params);
                }
            }
 
            $this->errors = array_unique($this->errors); // remove duplicate errors
 
            return $this->errors;
        }
 
        /**
         * Intercept resource calls so we can check them later
         *
         * @access private
         */
        function _compile_include_tag($tag_args)
        {
            $this->includes[] = $this->_parse_attrs($tag_args);
            return parent::_compile_include_tag($tag_args);
        }
 
        /**
         * Add the passed error to the return array
         *
         * @access private
         */
        function trigger_error($error_msg, $error_type = E_USER_WARNING)
        {
            $this->errors[] = ucfirst($error_msg);
        }
 
        /**
         * Handle a fatal error, such as a syntax error
         *
         * In normal Smarty, execution stops at this point, but
         * there's no way for us to do this and still return all errors
         * and validate resources, so just keep going. This may result in
         * extra irrelevant errors that would be resolved just from
         * fixing the initial fatal error
         *
         * @access private
         */
        function _trigger_fatal_error($error_msg, $tpl_file = null, $tpl_line = null,
                $file = null, $line = null, $error_type = E_USER_ERROR)
        {
            if (isset($tpl_line))
                $info = ' (line ' . $tpl_line . ')';
            else
                $info = '';
 
            $this->trigger_error($error_msg . $info, $error_type);
 
            // need a way to stop processing here ... ?
        }
    }
?>